@@ -58,12 +58,19 @@ class DriverNotInstalledError(Error):
 
 
 class DriverTooOldError(Error):
-    '''An error due to using this module with an older version of the driver runtime.'''
+    '''An error due to using this module with an older version of the NI Switch Executive driver runtime.'''
 
     def __init__(self):
         super(DriverTooOldError, self).__init__('A function was not found in the NI Switch Executive runtime. Please visit http://www.ni.com/downloads/drivers/ to download a newer version and install it.')
 
 
+class DriverTooNewError(Error):
+    '''An error due to the NI Switch Executive driver runtime being too new for this module.'''
+
+    def __init__(self):
+        super(DriverTooNewError, self).__init__('The NI Switch Executive runtime returned an unexpected value. This can occur if it is too new for the nise Python module. Upgrade the nise Python module.')
+
+
 class InvalidRepeatedCapabilityError(Error):
     '''An error due to an invalid character in a repeated capability'''
 
